@@ -1,8 +1,8 @@
 """
-Systematic CLI commands
+CLI utility toolkit
 
 This module implements python modules to implement command line tools,
 extending python argparse.ArgumentParser to make writing nested CLI
 commands easier.
 """
-__version__ = '1.0.2'
+__version__ = '1.1.1'
